exceptiontools.LineBreakError
=============================

.. abjad-lineage:: abjad.tools.exceptiontools.LineBreakError.LineBreakError

.. autoclass:: abjad.tools.exceptiontools.LineBreakError.LineBreakError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.LineBreakError.LineBreakError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LineBreakError.LineBreakError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LineBreakError.LineBreakError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LineBreakError.LineBreakError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LineBreakError.LineBreakError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LineBreakError.LineBreakError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LineBreakError.LineBreakError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.LineBreakError.LineBreakError.__unicode__
   :noindex:
